pub struct EncryptedPayload(/* private fields */);Expand description
These are detached encrypted bytes, which means they have a 0IRON + IV + CIPHERTEXT.
This value is correct by construction and will be validated when we create it.
There is no public constructor, only the TryFrom implementations.
Implementations
Sourceimpl EncryptedPayload
impl EncryptedPayload
Sourcepub fn to_aes_value_with_attached_iv(self) -> IvAndCiphertext
pub fn to_aes_value_with_attached_iv(self) -> IvAndCiphertext
Convert the encrypted payload to t
Sourcepub fn decrypt(self, key: &EncryptionKey) -> Result<PlaintextDocument, Error>
pub fn decrypt(self, key: &EncryptionKey) -> Result<PlaintextDocument, Error>
Decrypt a V5 detached document. The document should have the expected header
pub fn write_to_bytes(&self) -> Vec<u8> ⓘ